PasswordHashWorkFactor

Struct PasswordHashWorkFactor 

pub struct PasswordHashWorkFactor { /* private fields */ }
Argon2id work factor used when creating new password hashes.

Implementations

Source

impl PasswordHashWorkFactor

Returns the RFC 9106 second recommended Argon2id profile.

This uses 64 MiB of memory, three iterations, four lanes, and a 32-byte output.

pub fn new( memory_kib: u32, iterations: u32, parallelism: u32, output_length: usize, ) -> Result<Self>

Creates a custom Argon2id work factor.

Errors

Returns an error when the output length or Argon2 cost parameters fall outside the ranges accepted by the Argon2 implementation.

pub const fn memory_kib(self) -> u32

Memory cost in KiB.

pub const fn iterations(self) -> u32

Number of Argon2 passes.

pub const fn parallelism(self) -> u32

Number of Argon2 lanes.

pub const fn output_length(self) -> usize

Password-hash output length in bytes.