pub struct PasswordHashWorkFactor { /* private fields */ }Expand description
Argon2id work factor used when creating new password hashes.
Implementations
Sourceimpl PasswordHashWorkFactor
impl PasswordHashWorkFactor
Sourcepub const fn rfc_9106_second_recommended() -> Self
pub const fn rfc_9106_second_recommended() -> Self
Returns the RFC 9106 second recommended Argon2id profile.
This uses 64 MiB of memory, three iterations, four lanes, and a 32-byte output.
Sourcepub fn new(
memory_kib: u32,
iterations: u32,
parallelism: u32,
output_length: usize,
) -> Result<Self>
pub fn new( memory_kib: u32, iterations: u32, parallelism: u32, output_length: usize, ) -> Result<Self>
Creates a custom Argon2id work factor.
Errors
Returns an error when the output length or Argon2 cost parameters fall outside the ranges accepted by the Argon2 implementation.
Sourcepub const fn memory_kib(self) -> u32
pub const fn memory_kib(self) -> u32
Memory cost in KiB.
Sourcepub const fn iterations(self) -> u32
pub const fn iterations(self) -> u32
Number of Argon2 passes.
Sourcepub const fn parallelism(self) -> u32
pub const fn parallelism(self) -> u32
Number of Argon2 lanes.
Sourcepub const fn output_length(self) -> usize
pub const fn output_length(self) -> usize
Password-hash output length in bytes.